@@ -55,10 +55,11 @@ NULL
 
 #' @importFrom MatrixGenerics rowVars
 #' @importFrom stats model.matrix
+#' @importClassesFrom SparseArray COO_SparseMatrix SVT_SparseMatrix
 #' @importFrom scuttle fitLinearModel
 .get_variance_explained_internal <- function(block, variables) {
-    if (is(block, "SparseArraySeed")) {
-        block <- as(block, "dgCMatrix")
+    if (is(block, "COO_SparseMatrix")) {
+        block <- as(block, "SVT_SparseMatrix")
     }
 
     rsquared_mat <- matrix(NA_real_, nrow(block), ncol(variables), dimnames=list(NULL, colnames(variables))) 
