@@ -10,8 +10,8 @@
 #' detected expression values.
 #' @param other_fields Additional feature-based fields to include in the data.frame, see \code{?"\link{scater-plot-args}"} for details.
 #' Note that any \link{AsIs} vectors or data.frames must be of length equal to \code{nrow(object)}, not \code{features}.
-#' @param by_exprs_values A string or integer scalar specifying which assay to obtain expression values from, for entries of \code{other_fields}. 
-#' @param low_colour,high_colour,max_ave Deprecated arguments.
+#' @param by.assay.type A string or integer scalar specifying which assay to obtain expression values from, for entries of \code{other_fields}. Also alias \code{by_exprs_values} is accepted as argument name.
+#' @param by_exprs_values Alias for \code{by.assay.type}.
 #'
 #' @return 
 #' A \link{ggplot} object containing a dot plot.
@@ -19,8 +19,8 @@
 #' @details
 #' This implements a \pkg{Seurat}-style \dQuote{dot plot} that creates a dot for each feature (row) in each group of cells (column).
 #' The proportion of detected expression values and the average expression for each feature in each group of cells is visualized efficiently using the size and colour, respectively, of each dot.
-#' If \code{block} is specified, batch-corrected averages for each group are computed with \code{\link{correctGroupSummary}}.
-#' 
+#' If \code{block} is specified, batch-corrected averages and proportions for each group are computed with \code{\link{correctGroupSummary}}.
+#'
 #' Some caution is required during interpretation due to the difficulty of simultaneously interpreting both size and colour.
 #' For example, if we coloured by z-score on a conventional blue-white-red colour axis, a gene that is downregulated in a group of cells would show up as a small blue dot.
 #' If the background colour was also white, this could be easily mistaken for a gene that is not downregulated at all.
@@ -48,7 +48,7 @@
 #' for alternatives to visualizing group-level expression values.
 #'
 #' @export
-#' @importFrom ggplot2 ggplot aes_string geom_point
+#' @importFrom ggplot2 ggplot geom_point
 #' scale_size scale_colour_gradient theme element_line element_rect 
 #' scale_colour_gradient2
 #' @importFrom SummarizedExperiment assay
@@ -56,21 +56,14 @@
 plotDots <- function(object, features, group = NULL, block=NULL,
     exprs_values = "logcounts", detection_limit = 0, zlim = NULL, 
     colour = color, color = NULL,
-    max_detected = NULL, other_fields = list(), by_exprs_values = exprs_values,
-    swap_rownames = NULL, center = FALSE, scale = FALSE,
-    low_colour = NULL, high_colour = NULL, max_ave = NULL)
+    max_detected = NULL, other_fields = list(),
+    by_exprs_values = exprs_values,
+    swap_rownames = NULL,
+    center = FALSE,
+    scale = FALSE,
+    assay.type=exprs_values,
+    by.assay.type=by_exprs_values)
 {
-    # Handling all the deprecation.
-    if (!is.null(low_colour)) {
-        .Deprecated(msg="'low_colour=' is deprecated, use 'colour=' instead")
-    }
-    if (!is.null(high_colour)) {
-        .Deprecated(msg="'high_colour=' is deprecated, use 'colour=' instead")
-    }
-    if (!is.null(max_ave)) {
-        .Deprecated(msg="'max_ave=' is deprecated, use 'zlim=' instead")
-        zlim <- c(detection_limit, max_ave)
-    }
 
     if (is.null(group)) {
         group <- rep("all", ncol(object))
@@ -89,7 +82,7 @@ plotDots <- function(object, features, group = NULL, block=NULL,
     }
 
     summarized <- summarizeAssayByGroup(
-        assay(object, exprs_values)[as.character(features), , drop = FALSE],
+        assay(object, assay.type)[as.character(features), , drop = FALSE],
         ids=ids, statistics=c("mean", "prop.detected"),
         threshold=detection_limit)
     
@@ -100,7 +93,7 @@ plotDots <- function(object, features, group = NULL, block=NULL,
     if (!is.null(block)) {
         ave <- correctGroupSummary(ave, group=summarized$group, block=summarized$block)
         num <- correctGroupSummary(num, group=summarized$group, block=summarized$block, transform="logit")
-        group.names <- colnames(ave)
+        group.names <- factor(colnames(ave), levels = levels(summarized$group))
     }
     heatmap_scale <- .heatmap_scale(ave, center=center, scale=scale, colour=colour, zlim=zlim)
 
@@ -116,17 +109,17 @@ plotDots <- function(object, features, group = NULL, block=NULL,
     }
 
     # Adding other fields, if requested.
-    vis_out <- .incorporate_common_vis_row(evals_long, se = object, 
+    vis_out <- .incorporate_common_vis_row(evals_long, se = object,
         colour_by = NULL, shape_by = NULL, size_by = NULL, 
-        by_exprs_values = by_exprs_values, other_fields = other_fields,
+        by.assay.type = by.assay.type, other_fields = other_fields,
         multiplier = rep(.subset2index(features, object), ncol(num)))
     evals_long <- vis_out$df
     ggplot(evals_long) + 
-        geom_point(aes_string(x="Group", y="Feature", size="NumDetected", col="Average")) +
-        scale_size(limits=c(0, max(evals_long$NumDetected))) + 
+        geom_point(aes(x=.data$Group, y=.data$Feature, size=.data$NumDetected, col=.data$Average)) +
+        scale_size(limits=c(0, max(evals_long$NumDetected))) +
         heatmap_scale$colour_scale +
         theme(
             panel.background = element_rect(fill = "white"),
-            panel.grid.major = element_line(size=0.5, colour = "grey80"),
-            panel.grid.minor = element_line(size=0.25, colour = "grey80"))
+            panel.grid.major = element_line(linewidth=0.5, colour = "grey80"),
+            panel.grid.minor = element_line(linewidth=0.25, colour = "grey80"))
 }
