@@ -10,14 +10,15 @@
 #' @param colour_by Specification of a column metadata field or a feature to colour by, see the \code{by} argument in \code{?\link{retrieveCellInfo}} for possible values. 
 #' The curve for each cell will be coloured according to this specification.
 #' @param nfeatures Numeric scalar indicating the number of top-expressed features to show n the plot.
-#' @param exprs_values String or integer scalar indicating which assay of \code{object} should be used to obtain the expression values for this plot. 
-#' @param by_exprs_values A string or integer scalar specifying which assay to obtain expression values from, 
-#' for use in point aesthetics - see the \code{exprs_values} argument in \code{?\link{retrieveCellInfo}}.
+#' @param assay.type String or integer scalar indicating which assay of \code{object} should be used to obtain the expression values for this plot. 
+#' @param by.assay.type A string or integer scalar specifying which assay to obtain expression values from, 
+#' for use in point aesthetics - see the \code{assay.type} argument in \code{?\link{retrieveCellInfo}}.
 #' @param ncol Number of columns to use for \code{\link{facet_wrap}} if only one block is defined.
 #' @param line_width Numeric scalar specifying the line width.
 #' @param theme_size Numeric scalar specifying the font size to use for the plotting theme.
 #' @param color_by Alias to \code{colour_by}.
-#'
+#' @param exprs_values Alias to \code{assay.type}.
+#' @param by_exprs_values Alias to \code{by.assay.type}.
 #' @details 
 #' For each cell, the features are ordered from most-expressed to least-expressed.
 #' The cumulative proportion of the total expression for the cell is computed across the top \code{nfeatures} features. 
@@ -34,17 +35,20 @@
 #' @examples
 #' example_sce <- mockSCE()
 #' plotScater(example_sce)
-#' plotScater(example_sce, exprs_values = "counts", colour_by = "Cell_Cycle")
+#' plotScater(example_sce, assay.type = "counts", colour_by = "Cell_Cycle")
 #' plotScater(example_sce, block1 = "Treatment", colour_by = "Cell_Cycle")
 #'
 #' @export
 #' @importClassesFrom SingleCellExperiment SingleCellExperiment
 #' @importFrom SummarizedExperiment assay
-#' @importFrom ggplot2 ggplot geom_line facet_grid facet_wrap xlab ylab theme_bw aes_string
+#' @importFrom ggplot2 ggplot geom_line facet_grid facet_wrap xlab ylab theme_bw
 plotScater <- function(x, nfeatures = 500, exprs_values = "counts", 
     colour_by = color_by, by_exprs_values = exprs_values, 
     block1 = NULL, block2 = NULL, ncol = 3,
-    line_width = 1.5, theme_size = 10, color_by = NULL)
+    line_width = 1.5, theme_size = 10, color_by = NULL,
+    assay.type=exprs_values,
+    by.assay.type=by_exprs_values    
+    )
 {
     if (!is(x, "SingleCellExperiment")) {
         stop("x must be of class SingleCellExperiment")
@@ -52,19 +56,19 @@ plotScater <- function(x, nfeatures = 500, exprs_values = "counts",
     
     block1_out <- retrieveCellInfo(x, block1, search = "colData")
     block1 <- block1_out$name
-    block1_vals <- block1_out$val
+    block1_vals <- block1_out$value
 
     block2_out <- retrieveCellInfo(x, block2, search = "colData")
     block2 <- block2_out$name
-    block2_vals <- block2_out$val
+    block2_vals <- block2_out$value
 
     ## Setting values to colour by.
-    colour_by_out <- retrieveCellInfo(x, colour_by, exprs_values = by_exprs_values)
+    colour_by_out <- retrieveCellInfo(x, colour_by, assay.type = by.assay.type)
     colour_by <- colour_by_out$name
-    colour_by_vals <- colour_by_out$val
+    colour_by_vals <- colour_by_out$value
 
     ## Define an expression matrix depending on which values we're using
-    exprs_mat <- assay(x, i = exprs_values, withDimnames=FALSE)
+    exprs_mat <- assay(x, i = assay.type, withDimnames=FALSE)
     nfeatures <- min(nfeatures, nrow(exprs_mat))
 
     ## Use C++ to get the sequencing real estate accounted for by features
@@ -80,12 +84,12 @@ plotScater <- function(x, nfeatures = 500, exprs_values = "counts",
     seq_real_estate_long$colour_by <- rep(colour_by_vals, nfeatures)
 
     ## Set up plot
-    aes <- aes_string(x = "Feature", y = "Proportion_Library", group = "Cell")
+    aes <- aes(x = .data$Feature, y = .data$Proportion_Library, group = .data$Cell)
     if ( !is.null(colour_by) ) {
         aes$colour <- as.symbol("colour_by")
     }
     plot_out <- ggplot(seq_real_estate_long, aes) +
-        geom_line(linetype = "solid", alpha = 0.3, size = line_width)
+        geom_line(linetype = "solid", alpha = 0.3, linewidth = line_width)
 
     ## Deal with blocks for grid
     if (!is.null(block1) && !is.null(block2)) {
@@ -100,7 +104,10 @@ plotScater <- function(x, nfeatures = 500, exprs_values = "counts",
 
     ## Add extra plot theme and details
     if ( !is.null(colour_by)) { 
-        plot_out <- .resolve_plot_colours(plot_out, seq_real_estate_long$colour_by, colour_by)
+        plot_out <- .resolve_plot_colours(
+            plot_out, seq_real_estate_long$colour_by, colour_by,
+            fill = FALSE, colour = TRUE
+        )
     }
 
     plot_out <- plot_out + xlab("Number of features") + ylab("Cumulative proportion of library")
