@@ -101,6 +101,9 @@ NULL
 
     if (!external_neighbors || theta == 0) {
         if (use_fitsne) {
+            if (!requireNamespace("snifter")) {
+                stop("snifter is required for FI-tSNE.")
+            }
             if (use_densvis) {
                 warning("Can't use_fitsne and use_densvis at the same time; using fitsne")
             }
@@ -116,6 +119,9 @@ NULL
             )
         } else {
             if (use_densvis) {
+                if (!requireNamespace("densvis", quietly = TRUE)) {
+                    stop("densvis is not installed.")
+                }
                 args$dens_frac <- dens_frac
                 args$dens_lambda <- dens_lambda
                 tsne_out <- do.call(
